@@ -1,4 +1,5 @@
 import inspect
+from msilib.schema import CompLocator
 import pandas as pd
 import copy
 
@@ -157,20 +158,25 @@ class recset():
 
         """
         
-        # 行インスタンスをDeepCopy
-        targetRows = copy.deepcopy(self.rows)
-        # DataFrame化で不要な列を削除
-        for rowInstance in targetRows:
-            delattr(rowInstance, '_sa_instance_state')
-        # 行インスタンスをリスト化
-        rowlist = list(map(lambda f: vars(f), targetRows))
+        rowlist = []
+        if len(self.rows) == 0:
+            for column in self.__columns:
+                rowlist.append(column[0])
+        else:            
+            # 行インスタンスをDeepCopy
+            targetRows = copy.deepcopy(self.rows)
+            # DataFrame化で不要な列を削除
+            for rowInstance in targetRows:
+                delattr(rowInstance, '_sa_instance_state')
+            # 行インスタンスをリスト化
+            rowlist = list(map(lambda f: vars(f), targetRows))
 
         # rowlistをDataFrame変換
-        df = pd.DataFrame(rowlist)
+        df = pd.DataFrame(rowlist) if len(self.rows) > 0 else pd.DataFrame(columns=rowlist)
         
         # DataFrameに主キー設定
-        if len(self.__primaryKeys) > 0:
+        if len(self.__primaryKeys) > 0 and len(self.rows) > 0:
             df = df.set_index(self.__primaryKeys, drop=False)
-            
+                
         # 戻り値を返す
         return df
\ No newline at end of file
